Dictionary class
Constructors
- Dictionary({required DictionaryTrigger trigger, required DictionaryModal modal, required DictionarySuccesses successes, required DictionaryErrors errors})
-
const
Properties
- errors → DictionaryErrors
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- modal → DictionaryModal
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successes → DictionarySuccesses
-
final
- trigger → DictionaryTrigger
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited