DictionaryModal class

Constructors

DictionaryModal({required DictionaryModalTitles titles, required DictionaryModalSubTitles subTitles, required DictionaryModalActions actions, required DictionaryModalLabels labels, required DictionaryModalInfo info, required DictionaryModalWarnings warnings, required DictionaryModalSuccess success})
const

Properties

actions DictionaryModalActions
final
hashCode int
The hash code for this object.
no setterinherited
info DictionaryModalInfo
final
labels DictionaryModalLabels
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subTitles DictionaryModalSubTitles
final
success DictionaryModalSuccess
final
titles DictionaryModalTitles
final
warnings DictionaryModalWarnings
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited