DictionaryModalActions class

Constructors

DictionaryModalActions({required String back, required String close, required String support, required String scanApp, required String copy, required String copied, required String payFromDevice})
const

Properties

back String
final
close String
final
copied String
final
copy String
final
hashCode int
The hash code for this object.
no setterinherited
payFromDevice String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanApp String
final
support String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited