DictionaryModalInfo class

Constructors

DictionaryModalInfo({required String noReloadPageTitle, required String noReloadPageSubTitle, required String selectNetworkLater})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
noReloadPageSubTitle String
final
noReloadPageTitle String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectNetworkLater String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited