DictionaryModalLabels class

Constructors

DictionaryModalLabels({required String network, required String address, required String amount, required String product, required String minutes, required String seconds, required String amountSent, required String paid, required String remainingToPay})
const

Properties

address String
final
amount String
final
amountSent String
final
hashCode int
The hash code for this object.
no setterinherited
minutes String
final
network String
final
final
product String
final
remainingToPay String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seconds String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited