PaymentResponseData class

Constructors

PaymentResponseData({required String id, required String network, required String asset, required num amount, required String status})
PaymentResponseData.fromJson(Map<String, dynamic> json)
factory

Properties

amount num
final
asset String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
network String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited