QrResponseData class

Constructors

QrResponseData({required String id, required String network, required String asset, required num amount, required num amountPaid, required String address, required String qrCodeUrl, required int expiresAtMs, String? paymentUrl})
QrResponseData.fromJson(Map<String, dynamic> json)
factory

Properties

address String
final
amount num
final
amountPaid num
final
asset String
final
expiresAtMs int
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
network String
final
paymentUrl String?
final
qrCodeUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited