Asset class

Constructors

Asset({required String id, required String name, required String symbol, required String image, required List<Network> networks})
Asset.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
image String
final
name String
final
networks List<Network>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
final

Methods

copyWith({String? id, String? name, String? symbol, String? image, List<Network>? networks}) Asset
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

listFrom(List json) List<Asset>