ClientResponse<T extends dynamic> class

Inheritance

Constructors

ClientResponse({required ClientCode code, required String message, T? result})
ClientResponse.fromJson(Map<String, dynamic> json, {String? code, String? message, T result(dynamic)?})
factory

Properties

code ClientCode
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
result → T?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited