Repository class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fetchQrCodeDetails(
{required String publicKey, required String processId, required String assetId, required String networkId}) → Future< ClientResponse< QrResponseData> > -
getAssets(
) → Future< ClientResponse< List< >Asset> > -
getHeaders(
String? publicKey) → Map< String, String>