PaymentResponseData class
Constructors
- PaymentResponseData({required String id, required String network, required String asset, required num amount, required String status})
-
PaymentResponseData.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited