ClientCode enum
Values
- success → const ClientCode
-
const ClientCode('success') - paymentSuccess → const ClientCode
-
const ClientCode('payment_success') - paymentFailed → const ClientCode
-
const ClientCode('payment_failed') - paymentPartial → const ClientCode
-
const ClientCode('payment_partial') - paymentTimeout → const ClientCode
-
const ClientCode('payment_timeout') - connectError → const ClientCode
-
const ClientCode('connect_error') - socketConnectionError → const ClientCode
-
const ClientCode('socket_connection_error') - dataLoadError → const ClientCode
-
const ClientCode('data_load_error') - qrFetchError → const ClientCode
-
const ClientCode('qr_fetch_error') - paymentProcessNotAvailable → const ClientCode
-
const ClientCode('payment_process_not_available') - getAssetsError → const ClientCode
-
const ClientCode('get_assets_error') - unknownError → const ClientCode
-
const ClientCode('unknown_error')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ClientCode> - A constant List of the values in this enum, in order of their declaration.