ClientError class
- Inheritance
-
- Object
- ClientResponseBase
- ClientError
Constructors
- ClientError({required ClientCode code, required String message, dynamic error})
- ClientError.fromError(dynamic error, {ClientCode? code, String? message})
-
factory
Properties
- code → ClientCode
-
finalinherited
- error → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited